@@ -17,31 +17,31 @@ up to run as an e-mail filter will depend on your e-mail client.
 """
 
 import sys
+import socket
 
 from plib.classes import PTCPClient
 
 from emailfilterdefs import *
 
-class EMailFilterClient(PTCPClient, EMailFilterMixin):
+class EMailFilterClient(PTCPClient):
     """ Client class for email filter; creates a socket and
     connects it to the EMAILFILTERD.PY daemon. Its methods
     can then be called to send and receive data. """
     
+    bufsize = EMAILFILTER_BUFSIZE
     server_name = EMAILFILTER_NAME
     server_addr = EMAILFILTER_ADDR
     
-    def process_data(self, s):
-        if self.sock_result == 0:
-            self.send_data(s)
-            return self.recv_data()
-        
-        # If socket connection failed, pipe input direct to output
-        return s
+    def process_data(self):
+        sys.stdout.write(self.read_data)
 
 def main():
     s = sys.stdin.read()
-    r = EMailFilterClient().process_data(s) # client will auto-destruct
-    sys.stdout.write(r)
+    c = EMailFilterClient()
+    try:
+        c.client_communicate(s)
+    except socket.error:
+        sys.stdout.write(s)
 
 if __name__ == '__main__':
     main()
