@@ -11,8 +11,6 @@ Common definitions for emailfilter scripts.
 
 import os
 
-from plib.classes import SendReceiveMixin
-
 EMAILFILTER_NAME = "emailfilter"
 EMAILFILTER_BUFSIZE = 65536
 EMAILFILTER_HOSTNAME = "localhost"
@@ -21,7 +19,3 @@ EMAILFILTER_PORT = 5590 + os.getuid()
 EMAILFILTER_ADDR = (EMAILFILTER_HOSTNAME, EMAILFILTER_PORT)
 
 #EMAILFILTER_QUEUESIZE = 5 # queue size defaults to 5 in SocketServer anyway
-
-class EMailFilterMixin(SendReceiveMixin):
-    
-    bufsize = EMAILFILTER_BUFSIZE
